==> haskell-primitive-unlifted-0.1.3.1-1-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-primitive-unlifted.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 primitive-unlifted
version:              0.1.3.1
visibility:           public
id:                   primitive-unlifted-0.1.3.1-GzDUebrB1AYGGLlmqOJVHf
key:                  primitive-unlifted-0.1.3.1-GzDUebrB1AYGGLlmqOJVHf
license:              BSD-3-Clause
copyright:            2019 Andrew Martin
maintainer:           andrew.thaddeus@gmail.com
author:               Andrew Martin
homepage:             https://github.com/haskell-primitive/primitive-unlifted
synopsis:             Primitive GHC types with unlifted types inside
description:
    Primitive GHC types with unlifted types inside. There used
    to be a module named `Data.Primitive.UnliftedArray` in the
    `primitive` library. However, the techniques it used were
    unsound in the presence of certain FFI calls. This library
    a successor to that module.

category:             Data
abi:                  cf202f53b7c567cc7c012ed49bb93447
exposed:              True
exposed-modules:
    Data.Primitive.Unlifted.Array Data.Primitive.Unlifted.Class

import-dirs:          /usr/lib/ghc-9.0.2/site-local/primitive-unlifted-0.1.3.1
library-dirs:         /usr/lib/ghc-9.0.2/site-local/primitive-unlifted-0.1.3.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-primitive-unlifted
hs-libraries:         HSprimitive-unlifted-0.1.3.1-GzDUebrB1AYGGLlmqOJVHf
depends:
    base-4.15.1.0 bytestring-0.10.12.1
    primitive-0.7.4.0-CfTIpXUHtu665Ilg6bT1BW
    text-short-0.1.5-BpUmYQpnlq5B0lAlfuthm

haddock-interfaces:
    /usr/share/doc/haskell-primitive-unlifted/html/primitive-unlifted.haddock

haddock-html:         /usr/share/doc/haskell-primitive-unlifted/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-primitive-unlifted-0.1.3.1-3-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-primitive-unlifted.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 primitive-unlifted
version:              0.1.3.1
visibility:           public
id:                   primitive-unlifted-0.1.3.1-8NYhPTz8QWL94UtdiTXfCf
key:                  primitive-unlifted-0.1.3.1-8NYhPTz8QWL94UtdiTXfCf
license:              BSD-3-Clause
copyright:            2019 Andrew Martin
maintainer:           andrew.thaddeus@gmail.com
author:               Andrew Martin
homepage:             https://github.com/haskell-primitive/primitive-unlifted
synopsis:             Primitive GHC types with unlifted types inside
description:
    Primitive GHC types with unlifted types inside. There used
    to be a module named `Data.Primitive.UnliftedArray` in the
    `primitive` library. However, the techniques it used were
    unsound in the presence of certain FFI calls. This library
    a successor to that module.

category:             Data
abi:                  089c4e376ed489c202f7dae94d9e20b3
exposed:              True
exposed-modules:
    Data.Primitive.Unlifted.Array Data.Primitive.Unlifted.Class

import-dirs:          /usr/lib/ghc-9.0.2/site-local/primitive-unlifted-0.1.3.1
library-dirs:         /usr/lib/ghc-9.0.2/site-local/primitive-unlifted-0.1.3.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-primitive-unlifted
hs-libraries:         HSprimitive-unlifted-0.1.3.1-8NYhPTz8QWL94UtdiTXfCf
depends:
    base-4.15.1.0 bytestring-0.10.12.1
    primitive-0.7.4.0-9TVgKpsxQ9UKsTlz0zg7yv
    text-short-0.1.5-4VIXgAiCOCa4BannTLJtF6

haddock-interfaces:
    /usr/share/doc/haskell-primitive-unlifted/html/primitive-unlifted.haddock

haddock-html:         /usr/share/doc/haskell-primitive-unlifted/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
